import logging
import re
from typing import AnyStr, Pattern

logger = logging.getLogger(__name__)


def words_regex(*words):
    """Kelime arayan regex döndürme
    """
    pattern = []
    for word in words:
        pattern.append(r"\b" + word)

    return "|".join(pattern)


def rename_string(regex: Pattern[AnyStr], to: str, string: str) -> str:
    """Metni yeniden adlandırma

    Arguments:
        regex {Pattern[AnyStr]} -- Aranan regex
        to {str} -- Yeni isim
        path {str} -- Yol

    Returns:
        bool -- Adlandırma yapıldıysa true
    """
    result = regex.search(string)
    if result:
        if result.lastindex:
            for i in range(result.lastindex + 1):
                to = to.replace(f"${i}", result[i])

        string = regex.sub(to, string)

    return string


def compile_pattern(pattern, ignore_case=False) -> Pattern[AnyStr]:
    if ignore_case:
        p = re.compile(pattern, re.IGNORECASE)
    else:
        p = re.compile(pattern)

    return p


def remove_comments(filestr: str, commentstr: str) -> str:
    return re.sub(f"{commentstr}.*", "", filestr, flags=re.MULTILINE)



from threading import Thread, Timer


def do_background(func, args=(), kwargs={}):
    return Thread(target=func, args=args, kwargs=kwargs).start()


def do_delayed(func, duration, args=(), kwargs={}):
    return Timer(duration, func, args, kwargs).start()


def background(func):

    def inner(*args, **kwargs):
        do_background(func, args=args, kwargs=kwargs)

    return inner


def delayed(duration):
    def background(func):

        def inner(*args, **kwargs):
            do_delayed(func, duration, args=args, kwargs=kwargs)

        return inner
    return background


if __name__ == "__main__":

    @delayed(1)
    def test(val1, val2):
        for i in range(val1, val2):
            print(i)

    test(3, 20)



from setuptools import setup

VERSION = "2.7.4.1"
README_PATH = "docs/README.md"

# test_requirements = ['behave', 'behave-classy', 'pytest']

long_description = ""
with open(README_PATH, "r", encoding="utf-8") as file:
    long_description = file.read()


setup(
    name='ypackage',
    packages=['ypackage'],
    version=VERSION,
    description="Yunus Emre Ak ~ YEmreAk (@yedhrab)'ın google drive direkt link oluşturma" +
    "gitbook entegrasyonu, google arama motoru sonuçlarını filtreleme ile ilgili çalışmaları ",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Yunus Emre Ak',
    author_email="yemreak.com@gmail.com",
    license='Apache Software License 2.0',
    url='https://github.com/yedhrab/YPackage',
    keywords=[
        'ypackage', 'yedhrab', 'yemreak', 'gitbook', 'github',
        'google-search', "google", "link", "drive", "renamer", "bulk"
    ],
    install_requires=[
        "google",
        "requests",
        "pydriller",
        "coloredlogs"
    ],
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable"
        'Development Status :: 5 - Production/Stable',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    entry_points={
        # Komut isteminden çalıştırma
        # örndeğin: ypackage
        # Kullanım: 'ypacakge = ypackage.ypackage:main
        'console_scripts': [
            'ygitbookintegration = ypackage.cli.integrate_into_gitbook:main',
            "ygoogledrive = ypackage.cli.gdrive:main",
            "ygooglesearch = ypackage.cli.gsearch:main",
            "yfilerenamer = ypackage.cli.file_renamer:main",
            "ythemecreator = ypackage.cli.theme_creator:main"
        ]
    },
    # tests_require=test_requirements,
    include_package_data=True,
    zip_safe=False
)
